// -*- c++ -*-
/***************************************************************************
                           sourcemanager.cpp
                           -----------------
    begin                : Sun Sep 21 2003
    copyright            : (C) 2003 by Dirk Ziegelmeier
    email                : dziegel@gmx.de
    rcs data             : $Id: videowidgetimpl.h,v 1.1 2003/09/16 16:23:24 dziegel Exp $
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "sourcemanager.h"
#include "qvsrcplugin.h"
#include <kdebug.h>
#include "qtvision.h"
#include "pluginfactory.h"


SourceManager::SourceManager(QtVision *qtv)
    : _qtv(qtv)
{
    scanPlugins();
}

SourceManager::~SourceManager()
{
}

void SourceManager::scanPlugins()
{
    _devices.clear();
    _devicePluginMap.clear();
    _deviceSourcesMap.clear();
    _deviceEncodingsMap.clear();
    _deviceTunerMap.clear();

    QPtrList<PluginDesc>& sourcePlugins(_qtv->pluginFactory()->videoPlugins());
    for (PluginDesc* plug = sourcePlugins.first();
	 plug;
	 plug = sourcePlugins.next()) {
        kdDebug() << "Sourcemanager: Found a plugin: " << plug->name << endl;

        QVSourcePlugin* vsrc = _qtv->pluginFactory()->getSourcePlugin(plug, _qtv->screen());
        if (vsrc == 0) continue;
        vsrc->probeDevices();

        for (QStringList::ConstIterator it = vsrc->deviceList().begin();
	     it != vsrc->deviceList().end();
	     ++it) {
            kdDebug() << "Found device '" << *it << "' in plugin '" << plug->name << "'" << endl;
            kdDebug() << "Device contains " << vsrc->sourceList(*it).count() << " sources." << endl;

	    _devices.append(*it);
	    _devicePluginMap[*it]    = plug;
	    _deviceSourcesMap[*it]   = vsrc->sourceList(*it);
	    _deviceEncodingsMap[*it] = vsrc->encodingList(*it);
            _deviceTunerMap[*it]     = vsrc->isTuner(*it);
        }

        vsrc->destroy();
    }
    kdDebug() << "Sourcemanager: Done probing devices." << endl;
}

QVSourcePlugin* SourceManager::pluginFor(const QString& device)
{
    QVSourcePlugin* p = _qtv->pluginFactory()->getSourcePlugin(_devicePluginMap[device], _qtv->screen());
    if (p != 0) p->probeDevices();
    return p;
}

#include "sourcemanager.moc"
