// -*- c++ -*-
/***************************************************************************
                           sourcemanager.h
                           ---------------
    begin                : Sun Sep 21 2003
    copyright            : (C) 2003 by Dirk Ziegelmeier
    email                : dziegel@gmx.de
    rcs data             : $Id: videowidgetimpl.h,v 1.1 2003/09/16 16:23:24 dziegel Exp $
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _SOURCEMANAGER_H
#define _SOURCEMANAGER_H

#include <qobject.h>
#include <qmap.h>
#include <qstring.h>
#include <qstringlist.h>

class QVSourcePlugin;
class PluginDesc;

/**
 * Source plugins manager for QtVision.
 * Maintains lists of available plugins and devices.
 * @author Dirk Ziegelmeier
 */
class SourceManager : public QObject
{
    Q_OBJECT
	
public:
    /**
     * List of all available devices.
     */
    const QStringList&    deviceList() const                  { return _devices; };
    const QStringList&    sourcesFor(const QString& device)   { return _deviceSourcesMap[device]; };
    const QStringList&    encodingsFor(const QString& device) { return _deviceEncodingsMap[device]; };
    const bool            isTuner(const QString& device)      { return _deviceTunerMap[device]; };

    /**
     * Returns plugin that drives the supplied device.
     */
    QVSourcePlugin* pluginFor(const QString& device);


private:
    friend class QtVision;
    SourceManager(QtVision* qtv);
    ~SourceManager();

    /**
     * Loads all enabled video plugins and scans for devices, sources and encodings.
     * No sourceplugin should be in use when this is called.
     */
    void scanPlugins();

    QStringList                _devices;
    QMap<QString, PluginDesc*> _devicePluginMap;
    QMap<QString, QStringList> _deviceSourcesMap;
    QMap<QString, QStringList> _deviceEncodingsMap;
    QMap<QString, bool>        _deviceTunerMap;

    QtVision* _qtv;
};

#endif

